==> typo3-bootstrap-react-0.3.0.tgz: package/src/Components/Templates/ContentElements.ts <==
import Text from './ContentElements/Text'
import Textpic from './ContentElements/Textpic'
import Image from './ContentElements/Image'
import ImageLightbox from './ContentElements/Image'
import Div from './ContentElements/Div'
// import Textmedia from './ContentElements/Textmedia'
import Shortcut from './ContentElements/Shortcut'
import Html from './ContentElements/Html'
//import ImageModal from './ContentElements/ImageModal'
import Uploads from './ContentElements/Uploads'
import MenuSitemap from './ContentElements/MenuSitemap'


// import MenuSitemap from './ContentElements/MenuSitemap'

/* import FormFormFramework from './ContentElements/FormFormFramework'
import Html from './ContentElements/Html'

import List from './ContentElements/List'
import Login from './ContentElements/Login'
//import MenuAbstract from './ContentElements/MenuAbstract'
import MenuCategorizedContent from './ContentElements/MenuCategorizedContent'
import MenuCategorizedPages from './ContentElements/MenuCategorizedPages'
import MenuPages from './ContentElements/MenuPages'
import MenuRecentlyUpdated from './ContentElements/MenuRecentlyUpdated'
import MenuRelatedPages from './ContentElements/MenuRelatedPages'
//
import MenuSectionPages from './ContentElements/MenuSectionPages'
//import MenuSitemapPages from './ContentElements/MenuSitemapPages'
import MenuSubpages from './ContentElements/MenuSubpages'
import MenuSection from './ContentElements/MenuSection'*/

// import Table from './ContentElements/Table'


export {
  //  ImageModal,
    Text,
    Html,
    Textpic,
    Image,
    ImageLightbox,
    //Bullets,
    Div,
    /*  FormFormFramework,
   Html,
   List,
   Login,
 //  MenuAbstract,
   MenuCategorizedContent,
   MenuCategorizedPages,
   MenuPages,
   MenuRecentlyUpdated,
   MenuRelatedPages,
   MenuSection,
   MenuSectionPages,
 //
 //  MenuSitemapPages,
   MenuSubpages,*/
    //MenuSitemap,
    //  Table,
    Shortcut,
    //Image,
   // Textmedia,
    Uploads
}

==> typo3-bootstrap-react-0.4.0.tgz: package/src/Components/Templates/ContentElements.ts <==
import Text from './ContentElements/Text'
import Textpic from './ContentElements/Textpic'
import Image from './ContentElements/Image'
import ImageLightbox from './ContentElements/Image'
import Div from './ContentElements/Div'
import Textmedia from './ContentElements/Textmedia'
import Shortcut from './ContentElements/Shortcut'
import Html from './ContentElements/Html'
import Uploads from './ContentElements/Uploads'
import Accordion from "./ContentElements/Accordion";
import Gallery from "./ContentElements/Gallery";
import CardGroup from "./ContentElements/CardGroup";
import TextColumns from "./ContentElements/TextColumns";
import Quote from "./ContentElements/Quote";
import Header from "./ContentElements/Header";
//import ImageModal from './ContentElements/ImageModal'
//import MenuSitemap from './ContentElements/MenuSitemap'


// import MenuSitemap from './ContentElements/MenuSitemap'

/* import FormFormFramework from './ContentElements/FormFormFramework'
import Html from './ContentElements/Html'

import List from './ContentElements/List'
import Login from './ContentElements/Login'
//import MenuAbstract from './ContentElements/MenuAbstract'
import MenuCategorizedContent from './ContentElements/MenuCategorizedContent'
import MenuCategorizedPages from './ContentElements/MenuCategorizedPages'
import MenuPages from './ContentElements/MenuPages'
import MenuRecentlyUpdated from './ContentElements/MenuRecentlyUpdated'
import MenuRelatedPages from './ContentElements/MenuRelatedPages'
//
import MenuSectionPages from './ContentElements/MenuSectionPages'
//import MenuSitemapPages from './ContentElements/MenuSitemapPages'
import MenuSubpages from './ContentElements/MenuSubpages'
import MenuSection from './ContentElements/MenuSection'*/

// import Table from './ContentElements/Table'


export {
  //  ImageModal,
    Text,
    Html,
    Textpic,
    Image,
    ImageLightbox,
    //Bullets,
    Div,
    /*  FormFormFramework,
   Html,
   List,
   Login,
 //  MenuAbstract,
   MenuCategorizedContent,
   MenuCategorizedPages,
   MenuPages,
   MenuRecentlyUpdated,
   MenuRelatedPages,
   MenuSection,
   MenuSectionPages,
 //
 //  MenuSitemapPages,
   MenuSubpages,*/
    //MenuSitemap,
    //  Table,
    Shortcut,
   Textmedia,
    Uploads,
    Accordion,
    Gallery,
    CardGroup,
    TextColumns,
    Quote,
    Header,
}
